"""
Python module generated from Java source file dev.magicmq.pyspigot.PluginListener

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import *
from dev.magicmq.pyspigot.config import PluginConfig
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.util import StringUtils
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from org.bukkit import Bukkit
from org.bukkit.entity import Player
from org.bukkit.event import EventHandler
from org.bukkit.event import Listener
from org.bukkit.event.player import PlayerJoinEvent
from org.bukkit.event.server import PluginDisableEvent
from typing import Any, Callable, Iterable, Tuple


class PluginListener(Listener):
    """
    Main listener of the plugin. Currently used to listen for plugin disable (to disable scripts that depend on a disabled plugin) and to listen for player join to send PySpigot update messages.
    """

    def onDisable(self, event: "PluginDisableEvent") -> None:
        ...


    def onJoin(self, event: "PlayerJoinEvent") -> None:
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.config.PluginConfig

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.config import *
from java.time.format import DateTimeFormatter
from org.bukkit import ChatColor
from org.bukkit.configuration.file import FileConfiguration
from typing import Any, Callable, Iterable, Tuple


class PluginConfig:
    """
    Helper class to retrieve configuration values from the plugin config.
    """

    @staticmethod
    def reload() -> None:
        ...


    @staticmethod
    def getMetricsEnabled() -> bool:
        ...


    @staticmethod
    def getScriptLoadDelay() -> int:
        ...


    @staticmethod
    def getLibraryRelocations() -> dict[str, str]:
        ...


    @staticmethod
    def getLogTimestamp() -> "DateTimeFormatter":
        ...


    @staticmethod
    def doScriptActionLogging() -> bool:
        ...


    @staticmethod
    def doVerboseRedisLogging() -> bool:
        ...


    @staticmethod
    def doScriptUnloadOnPluginDisable() -> bool:
        ...


    @staticmethod
    def scriptOptionEnabled() -> bool:
        ...


    @staticmethod
    def scriptOptionLoadPriority() -> int:
        ...


    @staticmethod
    def scriptOptionPluginDepend() -> list[str]:
        ...


    @staticmethod
    def scriptOptionFileLoggingEnabled() -> bool:
        ...


    @staticmethod
    def scriptOptionMinLoggingLevel() -> str:
        ...


    @staticmethod
    def scriptOptionPermissionDefault() -> str:
        ...


    @staticmethod
    def scriptOptionPermissions() -> dict[Any, Any]:
        ...


    @staticmethod
    def shouldPrintStackTraces() -> bool:
        ...


    @staticmethod
    def shouldShowUpdateMessages() -> bool:
        ...


    @staticmethod
    def shouldUpdatePySpigotLib() -> bool:
        ...


    @staticmethod
    def getMessage(key: str, withPrefix: bool) -> str:
        ...


    @staticmethod
    def getPrefix() -> str:
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.command.PySpigotCommand

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.command import *
from dev.magicmq.pyspigot.command.subcommands import *
from dev.magicmq.pyspigot.config import PluginConfig
from dev.magicmq.pyspigot.util import StringUtils
from java.util import Arrays
from org.bukkit import ChatColor
from org.bukkit.command import Command
from org.bukkit.command import CommandSender
from org.bukkit.command import TabExecutor
from org.bukkit.entity import Player
from typing import Any, Callable, Iterable, Tuple


class PySpigotCommand(TabExecutor):

    def __init__(self):
        ...


    def onCommand(self, sender: "CommandSender", command: "Command", label: str, args: list[str]) -> bool:
        ...


    def onTabComplete(self, sender: "CommandSender", command: "Command", alias: str, args: list[str]) -> list[str]:
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.PySpigot

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import *
from dev.magicmq.pyspigot.command import PySpigotCommand
from dev.magicmq.pyspigot.config import PluginConfig
from dev.magicmq.pyspigot.config import ScriptOptionsConfig
from dev.magicmq.pyspigot.manager.command import CommandManager
from dev.magicmq.pyspigot.manager.config import ConfigManager
from dev.magicmq.pyspigot.manager.database import DatabaseManager
from dev.magicmq.pyspigot.manager.libraries import LibraryManager
from dev.magicmq.pyspigot.manager.listener import ListenerManager
from dev.magicmq.pyspigot.manager.placeholder import PlaceholderManager
from dev.magicmq.pyspigot.manager.protocol import ProtocolManager
from dev.magicmq.pyspigot.manager.redis import RedisManager
from dev.magicmq.pyspigot.manager.script import GlobalVariables
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.task import TaskManager
from dev.magicmq.pyspigot.util import StringUtils
from java.io import *
from java.net import URL
from java.net import URLConnection
from java.nio.file import Path
from java.nio.file import Paths
from java.util import Scanner
from org.bstats.bukkit import Metrics
from org.bstats.charts import SimplePie
from org.bukkit import Bukkit
from org.bukkit.command import PluginCommand
from org.bukkit.command import SimpleCommandMap
from org.bukkit.help import IndexHelpTopic
from org.bukkit.plugin import Plugin
from org.bukkit.plugin.java import JavaPlugin
from org.bukkit.scheduler import BukkitTask
from typing import Any, Callable, Iterable, Tuple


class PySpigot(JavaPlugin):
    """
    Main class of the plugin.
    """

    script = None
    """
    Can be used by scripts to access the ScriptManager.
    """
    global_vars = None
    """
    Can be used by scripts to access the GlobalVariables
    """
    listener = None
    """
    Can be used by scripts to access the ListenerManager.
    """
    command = None
    """
    Can be used by scripts to access the CommandManager.
    """
    scheduler = None
    """
    Can be used by scripts to access the TaskManager.
    """
    config = None
    """
    Can be used by scripts to access the ConfigManager.
    """
    protocol = None
    """
    Can be used by scripts to access the ProtocolManager.
    """
    placeholder = None
    """
    Can be used by scripts to access the PlaceholderManager.
    """
    database = None
    """
    Can be used by scripts to access the DatabaseManager
    """
    redis = None
    """
    Can be used by scripts to access the RedisManager
    """


    def onEnable(self) -> None:
        ...


    def onDisable(self) -> None:
        ...


    def reload(self) -> None:
        """
        Reload the plugin configuration.
        """
        ...


    def getPluginClassLoader(self) -> "ClassLoader":
        """
        Get the ClassLoader for PySpigot.

        Returns
        - The ClassLoader
        """
        ...


    def isPaper(self) -> bool:
        """
        Get if the server is running paper.

        Returns
        - True if the server is running paper, False if otherwise
        """
        ...


    def getDataFolderPath(self) -> "Path":
        """
        Get the path of the data folder for PySpigot.

        Returns
        - A path representing the data folder
        """
        ...


    def isProtocolLibAvailable(self) -> bool:
        """
        Check if ProtocolLib is available on the server.

        Returns
        - True if ProtocolLib is loaded and enabled, False if otherwise
        """
        ...


    def isPlaceholderApiAvailable(self) -> bool:
        """
        Check if PlacehodlerAPI is available on the server.

        Returns
        - True if PlaceholderAPI is loaded and enabled, False if otherwise
        """
        ...


    @staticmethod
    def get() -> "PySpigot":
        """
        Get the instance of this plugin.

        Returns
        - The instance
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.command.subcommands.HelpCommand

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.command import SubCommand
from dev.magicmq.pyspigot.command import SubCommandMeta
from dev.magicmq.pyspigot.command.subcommands import *
from dev.magicmq.pyspigot.config import PluginConfig
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from org.bukkit.command import CommandSender
from org.bukkit.entity import Player
from typing import Any, Callable, Iterable, Tuple


class HelpCommand(SubCommand):

    def onCommand(self, sender: "CommandSender", args: list[str]) -> bool:
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.command.CommandManager

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.manager.command import *
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.util import ReflectionUtils
from dev.magicmq.pyspigot.util import ScriptUtils
from java.lang.reflect import Field
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from org.bukkit import Bukkit
from org.bukkit.command import Command
from org.bukkit.command import SimpleCommandMap
from org.python.core import PyFunction
from typing import Any, Callable, Iterable, Tuple


class CommandManager:
    """
    Manager to interface with Bukkit's command framework. Primarily used by scripts to register and unregister commands.
    """

    def registerCommand(self, commandFunction: Callable, name: str) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - name: The name of the command to register

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, tabFunction: Callable, name: str) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - tabFunction: The tab function that should be called for tab completion of the command
        - name: The name of the command to register

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, name: str, description: str, usage: str) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - name: The name of the command to register
        - description: The description of the command
        - usage: The usage message for the command

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, tabFunction: Callable, name: str, description: str, usage: str) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - tabFunction: The tab function that should be called for tab completion of the command
        - name: The name of the command to register
        - description: The description of the command
        - usage: The usage message for the command

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, name: str, description: str, usage: str, aliases: list[str]) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - name: The name of the command to register
        - description: The description of the command
        - usage: The usage message for the command
        - aliases: A List of String containing all the aliases for this command

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, tabFunction: Callable, name: str, description: str, usage: str, aliases: list[str]) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - tabFunction: The tab function that should be called for tab completion of the command
        - name: The name of the command to register
        - description: The description of the command
        - usage: The usage message for the command
        - aliases: A List of String containing all the aliases for this command

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def registerCommand(self, commandFunction: Callable, tabFunction: Callable, name: str, description: str, usage: str, aliases: list[str], permission: str, permissionMessage: str) -> "ScriptCommand":
        """
        Register a new command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - commandFunction: The command function that should be called when the command is executed
        - tabFunction: The tab function that should be called for tab completion of the command. Can be null
        - name: The name of the command to register
        - description: The description of the command. Use an empty string for no description
        - usage: The usage message for the command
        - aliases: A List of String containing all the aliases for this command. Use an empty list for no aliases
        - permission: The required permission node to use this command. Can be null
        - permissionMessage: The message do display if there is insufficient permission to run the command. Can be null

        Returns
        - A ScriptCommand representing the command that was registered
        """
        ...


    def unregisterCommand(self, command: "ScriptCommand") -> None:
        """
        Unregister a script's command.
        
        **Note:** This should be called from scripts only!

        Arguments
        - command: The command to be unregistered
        """
        ...


    def unregisterCommands(self, script: "Script") -> None:
        """
        Unregister all commands belonging to a particular script.

        Arguments
        - script: The script from which all commands should be unregistered
        """
        ...


    def getCommand(self, script: "Script", name: str) -> "ScriptCommand":
        """
        Get a command associated with a particular script by the command name

        Arguments
        - script: The script
        - name: The name of the command

        Returns
        - The command with this name and associated with the script, or null if none was found
        """
        ...


    def getCommands(self, script: "Script") -> list["ScriptCommand"]:
        """
        Get an immutable list containing all commands belonging to a particular script.

        Arguments
        - script: The script to get commands from

        Returns
        - An immutable list containing all commands belonging to the script. Will return null if no commands belong to the script
        """
        ...


    @staticmethod
    def get() -> "CommandManager":
        """
        Get the singleton instance of this CommandManager

        Returns
        - The instance
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.listener.ListenerManager

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.manager.listener import *
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.util import ScriptUtils
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Method
from org.bukkit import Bukkit
from org.bukkit.event import Event
from org.bukkit.event import EventPriority
from org.bukkit.event import HandlerList
from org.python.core import PyFunction
from typing import Any, Callable, Iterable, Tuple


class ListenerManager:
    """
    Manager to interface with Bukkit's event framework. Primarily used by scripts to register and unregister event listeners.
    """

    def registerListener(self, function: Callable, eventClass: type["Event"]) -> "ScriptEventListener":
        """
        Register a new event listener with default priority.
        
        **Note:** This should be called from scripts only!

        Arguments
        - function: The function that should be called when the event occurs
        - eventClass: The type of event to listen to

        Returns
        - The ScriptEventListener that was registered
        """
        ...


    def registerListener(self, function: Callable, eventClass: type["Event"], priority: "EventPriority") -> "ScriptEventListener":
        """
        Register a new event listener.
        
        **Note:** This should be called from scripts only!

        Arguments
        - function: The function that should be called when the event occurs
        - eventClass: The type of event to listen to
        - priority: The priority of the event relative to other listeners

        Returns
        - The ScriptEventListener that was registered
        """
        ...


    def registerListener(self, function: Callable, eventClass: type["Event"], ignoreCancelled: bool) -> "ScriptEventListener":
        """
        Register a new event listener with default priority.
        
        **Note:** This should be called from scripts only!

        Arguments
        - function: The function that should be called when the event occurs
        - eventClass: The type of event to listen to
        - ignoreCancelled: If True, the event listener will not be called if the event has been previously cancelled by another listener.

        Returns
        - The ScriptEventListener that was registered
        """
        ...


    def registerListener(self, function: Callable, eventClass: type["Event"], priority: "EventPriority", ignoreCancelled: bool) -> "ScriptEventListener":
        """
        Register a new event listener.
        
        **Note:** This should be called from scripts only!

        Arguments
        - function: The function that should be called when the event occurs
        - eventClass: The type of event to listen to
        - priority: The priority of the event relative to other listeners
        - ignoreCancelled: If True, the event listener will not be called if the event has been previously cancelled by another listener.

        Returns
        - The ScriptEventListener that was registered
        """
        ...


    def unregisterListener(self, listener: "ScriptEventListener") -> None:
        """
        Unregister an event listener.
        
        **Note:** This should be called from scripts only!

        Arguments
        - listener: The listener to unregister
        """
        ...


    def getListeners(self, script: "Script") -> list["ScriptEventListener"]:
        """
        Get all event listeners associated with a script

        Arguments
        - script: The script to get event listeners from

        Returns
        - An immutable List of ScriptEventListener containing all events associated with the script. Will return null if there are no event listeners associated with the script
        """
        ...


    def getEventListener(self, script: "Script", eventClass: type["Event"]) -> "ScriptEventListener":
        """
        Get the event listener for a particular event associated with a script

        Arguments
        - script: The script
        - eventClass: The event

        Returns
        - The ScriptEventListener associated with the script and event, null if there is none
        """
        ...


    def unregisterListeners(self, script: "Script") -> None:
        """
        Unregister all event listeners belonging to a script.

        Arguments
        - script: The script whose event listeners should be unregistered
        """
        ...


    @staticmethod
    def get() -> "ListenerManager":
        """
        Get the singleton instance of this ListenerManager.

        Returns
        - The instance
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.task.SyncCallbackTask

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.task import *
from org.bukkit.scheduler import BukkitRunnable
from org.python.core import *
from typing import Any, Callable, Iterable, Tuple


class SyncCallbackTask(Task):
    """
    Represents an async task with a synchronous callback defined by a script.
    """

    def __init__(self, script: "Script", function: Callable, callbackFunction: Callable, functionArgs: list["Object"], delay: int):
        """
        Arguments
        - script: The script associated with this task
        - function: The script function that should be called when the async task executes
        - callbackFunction: The script function that should be called for the synchronous callback
        - functionArgs: Any arguments that should be passed to the function
        """
        ...


    def run(self) -> None:
        """
        Called internally when the task executes.
        """
        ...


    def toString(self) -> str:
        """
        Prints a representation of this SyncCallbackTask in string format, including the task ID, if it is async, and delay (if applicable)

        Returns
        - A string representation of the SyncCallbackTask
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.manager.placeholder.ScriptPlaceholder

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot.manager.placeholder import *
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from me.clip.placeholderapi.expansion import PlaceholderExpansion
from org.bukkit import OfflinePlayer
from org.python.core import *
from typing import Any, Callable, Iterable, Tuple


class ScriptPlaceholder(PlaceholderExpansion):
    """
    A class that represents a script placeholder expansion.
    
    A ScriptPlaceholder can have multiple individual placeholders. For example, a script with the name "test.py" could have "%script:test_placeholder1%" and "%script:test_placeholder2%". It will be up to the script to handle each individual placeholder.

    See
    - me.clip.placeholderapi.expansion.PlaceholderExpansion
    """

    def __init__(self, script: "Script", function: Callable, author: str, version: str):
        """
        Arguments
        - script: The script associated with this ScriptPlaceholder
        - function: The function to call when the placeholder is used
        - author: The author of this ScriptPlaceholder
        - version: The version of this ScriptPlaceholder
        """
        ...


    def getScript(self) -> "Script":
        """
        Get the script associated with this ScriptPlaceholder.

        Returns
        - The script associated with this ScriptPlaceholder
        """
        ...


    def getAuthor(self) -> str:
        """
        Get the author of this ScriptPlaceholder.

        Returns
        - The author of this ScriptPlaceholder
        """
        ...


    def getVersion(self) -> str:
        """
        Get the version of this ScriptPlaceholder.

        Returns
        - The version of this ScriptPlaceholder
        """
        ...


    def getIdentifier(self) -> str:
        """
        Get the identifier of this ScriptPlaceholder.
        
        This is used to identify the script's placeholder. It will be in the format "script:name", where "name" is the name of the script (without the file extension, .py). For example, for a script named "test.py", the placeholder identifier will be "script:test".

        Returns
        - The identifier of this ScriptPlaceholder
        """
        ...


    def persist(self) -> bool:
        """
        Indicates that the ScriptPlaceholder should persist when PlaceholderAPI is reloaded.

        Returns
        - True
        """
        ...


    def onRequest(self, player: "OfflinePlayer", params: str) -> str:
        """
        Called internally when the ScriptPlaceholder is used.

        Arguments
        - player: The org.bukkit.OfflinePlayer associated with the placeholder, or null if there is none
        - params: The specific placeholder that was used (the ScriptPlaceholder expansion can have multiple individual placeholders. Scripts will handle each specific placeholder on their own)

        Returns
        - The replaced text
        """
        ...



"""
Python module generated from Java source file dev.magicmq.pyspigot.command.subcommands.InfoCommand

Java source file obtained from artifact pyspigot version 0.7.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from dev.magicmq.pyspigot import PySpigot
from dev.magicmq.pyspigot.command import SubCommand
from dev.magicmq.pyspigot.command import SubCommandMeta
from dev.magicmq.pyspigot.command.subcommands import *
from dev.magicmq.pyspigot.manager.command import CommandManager
from dev.magicmq.pyspigot.manager.command import ScriptCommand
from dev.magicmq.pyspigot.manager.database import Database
from dev.magicmq.pyspigot.manager.database import DatabaseManager
from dev.magicmq.pyspigot.manager.listener import ListenerManager
from dev.magicmq.pyspigot.manager.listener import ScriptEventListener
from dev.magicmq.pyspigot.manager.placeholder import PlaceholderManager
from dev.magicmq.pyspigot.manager.placeholder import ScriptPlaceholder
from dev.magicmq.pyspigot.manager.protocol import ProtocolManager
from dev.magicmq.pyspigot.manager.protocol import ScriptPacketListener
from dev.magicmq.pyspigot.manager.redis import RedisManager
from dev.magicmq.pyspigot.manager.redis.client import ScriptRedisClient
from dev.magicmq.pyspigot.manager.script import Script
from dev.magicmq.pyspigot.manager.script import ScriptManager
from dev.magicmq.pyspigot.manager.script import ScriptOptions
from dev.magicmq.pyspigot.manager.task import Task
from dev.magicmq.pyspigot.manager.task import TaskManager
from dev.magicmq.pyspigot.util import StringUtils
from java.nio.file import Path
from java.time import Duration
from org.bukkit import ChatColor
from org.bukkit.command import CommandSender
from typing import Any, Callable, Iterable, Tuple


class InfoCommand(SubCommand):

    def onCommand(self, sender: "CommandSender", args: list[str]) -> bool:
        ...


    def onTabComplete(self, sender: "CommandSender", args: list[str]) -> list[str]:
        ...
